"""
    Kodexa is a Python framework to enable flexible data engineering with semi-structured and unstructured documents and
    data.
"""
from .cloud import RemoteSession, RemotePipeline, RemoteAction, KodexaPlatform
from .connectors import FolderConnector, FileHandleConnector, UrlConnector, registered_connectors, get_connectors, \
    get_connector, add_connector, get_source
from .extractors import *
from .model import DocumentMetadata, ContentNode, ContentFeature, SourceMetadata, \
    Document, LocalModelStore, RemoteStore, RemoteModelStore, DocumentStore
from .pipeline import Pipeline, PipelineStatistics, PipelineContext
from .sinks import InMemoryDocumentSink, FolderSink
from .steps import NodeTagger, TextParser, RollupTransformer, TagsToKeyValuePairExtractor
from .stores import JsonDocumentStore, TableDataStore, DictDataStore, DataStoreHelper, LocalDocumentStore, \
    RemoteDocumentStore



"""
Mix-ins
-------

Mix-ins are an effective way to add helper functionality to Documents and ContentNode's based on the underlying
features.
"""
from .core import CoreMixin
from .navigation import NavigationMixin
from .registry import get_mixin, get_renderers, add_mixin, apply_to_node, add_mixin_to_document, \
    add_mixins_to_document_node
from .spatial import SpatialMixin
from .util import add_method_to_node
